/*
    This file is part of ben -- a task scheduler for distributed computations
    Copyright (C) 2012-2023  Laurent Poirrier

    ben is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, version 3 of the License.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/
#include <time.h>
#include <stdio.h>
#include "xmem.h"
#include "date.h"

static char str[256];

int duration_str(char *s, size_t n, time_t dur)
{
	int dm, ds, dh, r;
	
	ds = dur % 60;
	dur /= 60;
	dm = dur % 60;
	dur /= 60;
	dh = dur;

	r = xsnprintf(s, n, "%02d:%02d:%02d", dh, dm, ds);
	
	return(r);
}

int duration_long_str(char *s, size_t n, time_t dur)
{
	int dm, ds, dh, dd, r;
	
	ds = dur % 60;
	dur /= 60;
	dm = dur % 60;
	dur /= 60;
	dh = dur % 24;
	dur /= 24;
	dd = dur;
	
	if (dd) {
		r = xsnprintf(s, n, "%4dd %02d:%02d:%02d", dd, dh, dm, ds);
	} else {
		r = xsnprintf(s, n, "      %02d:%02d:%02d", dh, dm, ds);
	}
	
	return(r);
}

int date_str(char *s, size_t n, time_t t)
{
	struct tm *bd;
	int r;
	
	bd = localtime(&t);
	
	r = xsnprintf(s, n, "%04d-%02d-%02d %02d:%02d:%02d",
		1900 + bd->tm_year, 1 + bd->tm_mon, bd->tm_mday,
		bd->tm_hour, bd->tm_min, bd->tm_sec);
	
	return(r);
}

char *curdate_str()
{
	date_str(str, sizeof(str), time(NULL));
	return(str);
}


